<img src="https://raw.githubusercontent.com/nationalarchives/tna-frontend/main/src/nationalarchives/assets/images/tna-square-logo.svg" alt="The National Archives logo" title="The National Archives" width="100" />

# National Archives Python Utilities

[![Main build status](https://img.shields.io/github/actions/workflow/status/nationalarchives/python-utilities/ci.yml?style=flat-square&event=push&branch=main)](https://github.com/nationalarchives/python-utilities/actions/workflows/ci.yml?query=branch%3Amain)
[![Latest release](https://img.shields.io/github/v/release/nationalarchives/python-utilities?style=flat-square&logo=github&logoColor=white&sort=semver)](https://github.com/nationalarchives/python-utilities/releases)
[![PyPi version](https://img.shields.io/pypi/v/tna-utilities?style=flat-square&logo=pypi&logoColor=white)](https://pypi.org/project/tna-utilities/)
![Python version](https://img.shields.io/pypi/pyversions/tna-utilities?style=flat-square&logo=python&logoColor=white)
[![Licence](https://img.shields.io/github/license/nationalarchives/python-utilities?style=flat-square)](https://github.com/nationalarchives/python-utilities/blob/main/LICENCE)

A library of common National Archives Python functions.

See the [documentation](https://nationalarchives.github.io/python-utilities/).

## Install

```sh
# Install with Poetry
poetry add tna-utilities

# Install with pip
pip install tna-utilities
```

## Developing

```sh
# Run the tests
python -m unittest discover test

# Format the code
./tasks/format.sh
```
